=====
Tiote
=====

Tiote enables django websites to administer PostgreSQL and MySQL databases. It provides a clean and intuitive interface to your database(s) with which you can use Database level functions. This functions can be summarised as CRUD (Create, Read, Update and Delete). It has been tested both on linux (ubuntu), and epio (https://ep.io) environments.


Screenshots
===========

database overview
-----------------

.. image:: https://github.com/dumb906/tiote/raw/master/docs/images/db_overview.png

editing table data
------------------
.. image:: https://github.com/dumb906/tiote/raw/master/docs/images/edit_table_data.png


Tiote is more than an app
=========================

Besides using tiote as an app in your django setup you can also use it as a standalone server to manage, monitor and your databases no matter they way they were created and are maintained.

Though a django app it can also be used by other stacks and setups though its primary implementation uses django and python. 

Resources
=========

* `Documentation <http://tiote.readthedocs.org/en/latest/>`_

* `Bug Tracker <http://github.com/dumb906/tiote/issues>`_

* `Mailing List <https://groups.google.com/group/tiote>`_
